"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getJwkFromKey = exports.getKeyDataFromJwk = void 0;
const utils_1 = require("../utils");
const EcCompression_1 = require("./EcCompression");
const JwkTypes_1 = require("./JwkTypes");
const KeyType_1 = require("./KeyType");
function getKeyDataFromJwk(jwk) {
    // ed25519, x25519
    if ((0, JwkTypes_1.isEd25519JwkPublicKey)(jwk) || (0, JwkTypes_1.isX25519JwkPublicKey)(jwk)) {
        return {
            publicKey: utils_1.TypedArrayEncoder.fromBase64(jwk.x),
            keyType: JwkTypes_1.jwkCurveToKeyTypeMapping[jwk.crv],
        };
    }
    // p-256, p-384, p-521
    if ((0, JwkTypes_1.isP256JwkPublicKey)(jwk) || (0, JwkTypes_1.isP384JwkPublicKey)(jwk) || (0, JwkTypes_1.isP521JwkPublicKey)(jwk)) {
        // TODO: do we want to use the compressed key in the Key instance?
        const publicKeyBuffer = utils_1.Buffer.concat([utils_1.TypedArrayEncoder.fromBase64(jwk.x), utils_1.TypedArrayEncoder.fromBase64(jwk.y)]);
        const compressedPublicKey = (0, EcCompression_1.compress)(publicKeyBuffer);
        return {
            publicKey: compressedPublicKey,
            keyType: JwkTypes_1.jwkCurveToKeyTypeMapping[jwk.crv],
        };
    }
    throw new Error(`Unsupported JWK kty '${jwk.kty}' and crv '${jwk.crv}'`);
}
exports.getKeyDataFromJwk = getKeyDataFromJwk;
function getJwkFromKey(key) {
    if (key.keyType === KeyType_1.KeyType.Ed25519 || key.keyType === KeyType_1.KeyType.X25519) {
        return {
            kty: 'OKP',
            crv: JwkTypes_1.keyTypeToJwkCurveMapping[key.keyType],
            x: utils_1.TypedArrayEncoder.toBase64URL(key.publicKey),
        };
    }
    if (key.keyType === KeyType_1.KeyType.P256 || key.keyType === KeyType_1.KeyType.P384 || key.keyType === KeyType_1.KeyType.P521) {
        const crv = JwkTypes_1.keyTypeToJwkCurveMapping[key.keyType];
        const expanded = (0, EcCompression_1.expand)(key.publicKey, crv);
        const x = expanded.slice(0, expanded.length / 2);
        const y = expanded.slice(expanded.length / 2);
        return {
            kty: 'EC',
            crv,
            x: utils_1.TypedArrayEncoder.toBase64URL(x),
            y: utils_1.TypedArrayEncoder.toBase64URL(y),
        };
    }
    throw new Error(`Cannot encode Key as JWK. Unsupported key type '${key.keyType}'`);
}
exports.getJwkFromKey = getJwkFromKey;
//# sourceMappingURL=Jwk.js.map